# Speed Calculator
A library to speed calculation of a function.
# Install
```
pip3 install speed-calculator
```
# Using
```python
from speed_calculator import calculate

import time
def a_function():
    time.sleep(2)

print(calculate(a_function))
```